@@ -1,6 +1,8 @@
+import struct
 from ctypes.wintypes import DWORD
 from ctypes import windll, create_string_buffer, pointer
 
+
 from .bindings import get_firmware_environment_variable_ex_w
 
 
@@ -37,3 +39,13 @@ def utf16_string_from_bytes(raw):
 
 def string_to_utf16_bytes(string):
     return string.encode('utf-16le') + b'\x00\x00'
+
+
+def iter_unpack(format, buffer):
+    def chunks(data, chunk_size):
+        for i in range(0, len(data), chunk_size):
+            yield data[i:i+chunk_size]
+
+    s = struct.Struct(format)
+    for chunk in chunks(buffer, s.size):
+        yield s.unpack(chunk)
