@@ -1,6 +1,6 @@
 from ctypes import create_string_buffer, pointer, WinError
 from ctypes.wintypes import DWORD
-from enum import IntFlag
+from aenum import IntFlag
 
 from .utils import gle, verify_uefi_firmware
 from .bindings import get_firmware_environment_variable_ex_w, set_firmware_environment_variable_ex_w
@@ -50,7 +50,7 @@ def get_variable(name, namespace=GLOBAL_NAMESPACE):
 
         if stored_bytes != 0:
             return buffer.raw[:stored_bytes], Attributes(attributes.value)
-        elif stored_bytes == 0 and gle() == ERROR_BUFFER_TOO_SMALL:
+        elif gle() == ERROR_BUFFER_TOO_SMALL:
             allocation *= 2
         else:
             raise WinError()
